@@ -1,7 +1,7 @@
 #ifndef _PROVALUE_H
 #define _PROVALUE_H	1
 
-PSTRING get_variable_value (struct tmplpro_param *param, PSTRING name);
+PSTRING _get_variable_value (struct tmplpro_param *param, PSTRING name);
 
 #endif /* provalue.h */
 
